@@ -18,7 +18,7 @@ void efxc2Compiler::Compiler::Preprocess() {
 		efxc2Utils::print_no_input_file();
 		throw efxc2Exception::NoInputFile();
 	}
-	size_t SourceLen = SourceCode->size();  //-	V2571 //-V3546 //-V2571
+	size_t SourceLen = SourceCode->size(); 
 	auto  includeDirs = params.get_includeDirs();
 	std::string _inputFile = params.get_inputFile();
 	const char* inputFile = _inputFile.c_str();
@@ -113,7 +113,7 @@ void efxc2Compiler::Compiler::Compile() {
 		efxc2Utils::print_no_input_file();
 		throw efxc2Exception::NoInputFile();
 	}
-	size_t SourceLen = SourceCode->size();  //-V2571 //-V3546
+	size_t SourceLen = SourceCode->size(); 
 	auto eflags = params.get_eflags();
 	auto sflags = params.get_sflags();
 	auto secondary_flags = params.get_secondary_flags();
@@ -405,8 +405,12 @@ std::string efxc2Compiler::Compiler::GetPDBFileName() {
 		efxc2Utils::print_hresult_error(hr);
 		throw efxc2Exception::Win32HLSLFailure();
 	}
-	auto pDebugNameData = std::bit_cast<ShaderDebugName*>(pPDBName->GetBufferPointer());
-	auto pName = std::bit_cast<char*>(&pDebugNameData[1]);  //-V2563 //-V3539
+	char* pName = std::bit_cast<char*>(pPDBName->GetBufferPointer());
+	/* Skip over reserved feild - uint_16 and length field uint_16*/
+	++pName;
+	++pName;
+	++pName;
+	++pName;
 	if (params.get_verbose()) {
 		std::cout << std::format(".PDB Data Name: {}\n", pName);
 	}
@@ -417,7 +421,7 @@ void efxc2Compiler::Compiler::EmbedPrivateData() {
 	auto const* compiledString = std::bit_cast<unsigned char*>(compilerOutput->GetBufferPointer());
 	size_t compiledLen = compilerOutput->GetBufferSize();
 	auto private_data = params.get_PrivateData();
-	size_t private_data_size = private_data->size();  //-V2571 //-V3546
+	size_t private_data_size = private_data->size();  
 	if (params.get_verbose() && params.get_debug()) {
 		std::cout << "Calling D3DSetBlobPart(\n";
 		std::cout << "\t compiledString,\n";
@@ -471,9 +475,8 @@ void efxc2Compiler::Compiler::SetPDBFileName(_In_ const std::string_view _fileNa
 
 	header->Flags = 0;
 	// declared length does not include the null terminator:
-	// The typcast to uint16_t is deliberate because that struct stores a 16 bit value
-	// so let's mark this as a false positive.
-	header->NameLength = (uint16_t)(fileNameLen - 1);  //-V2005 //-V2533
+	// The typcast to uint16_t is deliberate because that struct stores a 16 bit value,
+	header->NameLength = static_cast<uint16_t>(fileNameLen - 1);
 	// but the null terminator is expected to be present:
 	for (size_t i = 0; i < fileNameLen; i++) {
 		pNameBlobContent[sizeof(ShaderDebugName) + i] = _fileName[i];
